@@ -5,7 +5,11 @@ class Gon
       JS_FUNCTION = File.read(File.expand_path('../../../js/watch.js', __FILE__))
 
       def render
-        JS_FUNCTION + "window.gon.watchedVariables=#{all_variables.to_json};"
+        JS_FUNCTION + "window.gon.watchedVariables=#{Gon::JsonDumper.dump all_variables};"
+      end
+
+      def render_amd
+        JS_FUNCTION + "gon.watchedVariables=#{Gon::JsonDumper.dump all_variables};"
       end
 
       def all_variables
@@ -46,7 +50,7 @@ class Gon
 
       def return_variable(value)
         controller = Gon::Base.get_controller
-        controller.render :json => value
+        controller.render json: Gon::Escaper.escape_unicode(Gon::JsonDumper.dump value)
       end
 
     end
